==> appstream-glib_0.3.0.orig.tar.xz: appstream-glib-0.3.0/libappstream-glib/as-screenshot-private.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#if !defined (__APPSTREAM_GLIB_PRIVATE_H) && !defined (AS_COMPILATION)
#error "Only <appstream-glib.h> can be included directly."
#endif

#ifndef __AS_SCREENSHOT_PRIVATE_H
#define __AS_SCREENSHOT_PRIVATE_H

#include <glib-object.h>

#include "as-screenshot.h"

G_BEGIN_DECLS

GNode		*as_screenshot_node_insert	(AsScreenshot	*screenshot,
						 GNode		*parent,
						 gdouble	 api_version);
gboolean	 as_screenshot_node_parse	(AsScreenshot	*screenshot,
						 GNode		*node,
						 GError		**error);
gboolean	 as_screenshot_node_parse_dep11	(AsScreenshot	*screenshot,
						 GNode		*node,
						 GError		**error);

G_END_DECLS

#endif /* __AS_SCREENSHOT_PRIVATE_H */

==> appstream-glib_0.5.13.orig.tar.xz: appstream-glib-0.5.13/libappstream-glib/as-screenshot-private.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#if !defined (__APPSTREAM_GLIB_PRIVATE_H) && !defined (AS_COMPILATION)
#error "Only <appstream-glib.h> can be included directly."
#endif

#ifndef __AS_SCREENSHOT_PRIVATE_H
#define __AS_SCREENSHOT_PRIVATE_H

#include <glib-object.h>

#include "as-screenshot.h"
#include "as-node-private.h"

G_BEGIN_DECLS

GNode		*as_screenshot_node_insert	(AsScreenshot	*screenshot,
						 GNode		*parent,
						 AsNodeContext	*ctx);
gboolean	 as_screenshot_node_parse	(AsScreenshot	*screenshot,
						 GNode		*node,
						 AsNodeContext	*ctx,
						 GError		**error);
gboolean	 as_screenshot_node_parse_dep11	(AsScreenshot	*screenshot,
						 GNode		*node,
						 AsNodeContext	*ctx,
						 GError		**error);

G_END_DECLS

#endif /* __AS_SCREENSHOT_PRIVATE_H */
